==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/RowSeparatorInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { RowSeparatorInfoDescription } from "./RowSeparatorInfoDescription";
/**
 * @hidden
 */
export let RowSeparatorInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class RowSeparatorInfoDescriptionMetadata extends Base {
        static b(a) {
            if (RowSeparatorInfoDescriptionMetadata.a == null) {
                RowSeparatorInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RowSeparatorInfoDescriptionMetadata.c(RowSeparatorInfoDescriptionMetadata.a);
            }
            if (a.j(RowSeparatorInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(RowSeparatorInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            RowSeparatorInfoDescriptionMetadata.b(a);
            a.aa("RowSeparatorInfo", () => new RowSeparatorInfoDescription());
            a.z("RowSeparatorInfo", RowSeparatorInfoDescriptionMetadata.a);
        }
    }
    RowSeparatorInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(RowSeparatorInfoDescriptionMetadata, 'RowSeparatorInfoDescriptionMetadata');
    RowSeparatorInfoDescriptionMetadata.a = null;
    return RowSeparatorInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RowSeparatorInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { RowSeparatorInfoDescription } from "./RowSeparatorInfoDescription";
/**
 * @hidden
 */
export let RowSeparatorInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class RowSeparatorInfoDescriptionMetadata extends Base {
        static b(a) {
            if (RowSeparatorInfoDescriptionMetadata.a == null) {
                RowSeparatorInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RowSeparatorInfoDescriptionMetadata.c(RowSeparatorInfoDescriptionMetadata.a);
            }
            if (a.k(RowSeparatorInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(RowSeparatorInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            RowSeparatorInfoDescriptionMetadata.b(a);
            a.ac("RowSeparatorInfo", () => new RowSeparatorInfoDescription());
            a.ab("RowSeparatorInfo", RowSeparatorInfoDescriptionMetadata.a);
        }
    }
    RowSeparatorInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(RowSeparatorInfoDescriptionMetadata, 'RowSeparatorInfoDescriptionMetadata');
    RowSeparatorInfoDescriptionMetadata.a = null;
    return RowSeparatorInfoDescriptionMetadata;
})();
